"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const allowedKeys = [
    'exclude',
];
class Validator {
    static validatePermitted(node, rules) {
        if (!rules) {
            return true;
        }
        return rules.some(rule => {
            return Validator.validatePermittedRule(node, rule);
        });
    }
    static validatePermittedRule(node, rule) {
        if (typeof rule === 'string') {
            return Validator.validatePermittedCategory(node, rule);
        }
        else if (Array.isArray(rule)) {
            return rule.every((inner) => {
                return Validator.validatePermittedRule(node, inner);
            });
        }
        else {
            validateKeys(rule);
            if (rule.exclude) {
                if (Array.isArray(rule.exclude)) {
                    return !rule.exclude.some((inner) => {
                        return Validator.validatePermittedRule(node, inner);
                    });
                }
                else {
                    return !Validator.validatePermittedRule(node, rule.exclude);
                }
            }
            else {
                return false;
            }
        }
    }
    static validatePermittedCategory(node, category) {
        if (category[0] !== '@') {
            return node.tagName === category;
        }
        if (!node.meta) {
            return true;
        }
        switch (category) {
            case '@meta': return node.meta.metadata;
            case '@flow': return node.meta.flow;
            case '@sectioning': return node.meta.sectioning;
            case '@heading': return node.meta.heading;
            case '@phrasing': return node.meta.phrasing;
            case '@embedded': return node.meta.embedded;
            case '@interactive': return node.meta.interactive;
            default: throw new Error(`Invalid content category "${category}"`);
        }
    }
}
exports.Validator = Validator;
function validateKeys(rule) {
    for (const key of Object.keys(rule)) {
        if (allowedKeys.indexOf(key) === -1) {
            const str = JSON.stringify(rule);
            throw new Error(`Permitted rule "${str}" contains unknown property "${key}"`);
        }
    }
}
