"use strict";
const meta_1 = require("../meta");
function init(parser) {
    parser.on('dom:ready', validate);
}
function validate(event, report) {
    const doc = event.document;
    doc.visitDepthFirst((node) => {
        if (node.parent.isRootElement()) {
            return;
        }
        if (!node.parent.meta) {
            return;
        }
        const parent = node.parent;
        const rules = parent.meta.permittedContent;
        validatePermittedContent(node);
        validatePermittedDescendant(parent);
        function validatePermittedContent(cur) {
            if (!meta_1.Validator.validatePermitted(cur, rules)) {
                report(cur, `Element <${cur.tagName}> is not permitted as content in <${parent.tagName}>`);
                return;
            }
            if (cur.meta && cur.meta.transparent) {
                cur.children.forEach((child) => {
                    validatePermittedContent(child);
                });
            }
        }
        function validatePermittedDescendant(cur) {
            while (!cur.isRootElement()) {
                if (cur.meta && node.meta && !meta_1.Validator.validatePermitted(node, cur.meta.permittedDescendants)) {
                    report(node, `Element <${node.tagName}> is not permitted as descendant of <${cur.tagName}>`);
                    return;
                }
                cur = cur.parent;
            }
        }
    });
}
module.exports = {
    name: 'element-permitted-content',
    init,
};
